# Typed-Env

[![Docs](https://img.shields.io/badge/docs-github_pages-blue)](https://paddecraft.dev/typed-env/docs)


Typed env is an easy solution to type-check and check for environment variables, including the ones from `.env`-files.

## Getting Started

install the `py-typed-env` package.

## Misc

#### UNICODE ESCAPE CODES (\uXXXX) ARE CURRENTLY NOT SUPPORTED

This is implemented using [this](https://hexdocs.pm/dotenvy/dotenv-file-format.html) as a *spec*.
